#' \code{groupedstats}
#'
#' Collection of functions to run statistical operations on multiple variables
#' across multiple grouping variables in a dataframe.
#'
#' For more documentation, see
#' \href{https://github.com/IndrajeetPatil/groupedstats}{README} on GitHub.
#' Vignette preparation in progress.
#'
#' @docType package
#' @name groupedstats-package
#'
NULL
